@@ -13,16 +13,16 @@ class Brain:
         self.init(self.modeSwitcher[mode])
     def init(self, mode):
         tf.get_logger().setLevel('ERROR')
-        tf.autograph.set_verbosity(0)
+        tf.autograph.set_verbosity(Config.get("NORMALIZATION_ENABLED"))
         self.model = load_model(mode)
 
     def predict(self, image):
         prediction = self.model.predict(image)
         result = {
-            True: "Wandering",
-            False: "Not Wandering"
+            True: Config.get("RESULT_MAP")["WANDER"],
+            False: Config.get("RESULT_MAP")["NORMAL"]
         }
-        prediction = [prediction > 0.5]
+        prediction = [prediction > Config.get("RESULT_THRESHOLD")]
         return result[prediction[0][0][0]]
 
     def predict_profiler(self, image):
