@@ -39,8 +39,10 @@ class Image:
     def process(self):
         image = self.decode(self.image)
         image = np.array(image)
-        image = self.resize(image)
-        image = self.normalize(image)
+        if Config.get("RESIZE_ENABLED"):
+            image = self.resize(image)
+        if Config.get("NORMALIZATION_ENABLED"):
+            image = self.normalize(image)
         image = image[np.newaxis, ..., np.newaxis]
         self.image = image
         return image
